@@ -311,7 +311,7 @@ class ProfilePlot(DashboardComponent):
         state = profile.create()
         data = profile.plot_data(state, profile_interval)
         self.states = data.pop('states')
-        self.source = ColumnDataSource(data=data)
+        self.root, self.source = profile.plot_figure(data, **kwargs)
 
         @without_property_validation
         def cb(attr, old, new):
@@ -335,45 +335,6 @@ class ProfilePlot(DashboardComponent):
         else:
             self.source.on_change('selected', cb)
 
-        self.root = figure(tools='tap', **kwargs)
-        self.root.quad('left', 'right', 'top', 'bottom', color='color',
-                      line_color='black', line_width=2, source=self.source)
-
-        hover = HoverTool(
-            point_policy="follow_mouse",
-            tooltips="""
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Name:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@name</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Filename:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@filename</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Line number:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@line_number</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Line:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@line</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Time:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@time</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Percentage:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@width</span>
-                </div>
-                """
-        )
-        self.root.add_tools(hover)
-
-        self.root.xaxis.visible = False
-        self.root.yaxis.visible = False
-        self.root.grid.visible = False
-
     @without_property_validation
     def update(self, state):
         with log_errors():
@@ -412,7 +373,7 @@ class ProfileTimePlot(DashboardComponent):
         self.state = profile.create()
         data = profile.plot_data(self.state, profile_interval)
         self.states = data.pop('states')
-        self.source = ColumnDataSource(data=data)
+        self.profile_plot, self.source = profile.plot_figure(data, **kwargs)
 
         changing = [False]  # avoid repeated changes from within callback
 
@@ -445,47 +406,6 @@ class ProfileTimePlot(DashboardComponent):
         else:
             self.source.on_change('selected', cb)
 
-        self.profile_plot = figure(tools='tap', height=400, **kwargs)
-        r = self.profile_plot.quad('left', 'right', 'top', 'bottom', color='color',
-                                   line_color='black', source=self.source)
-        r.selection_glyph = None
-        r.nonselection_glyph = None
-
-        hover = HoverTool(
-            point_policy="follow_mouse",
-            tooltips="""
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Name:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@name</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Filename:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@filename</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Line number:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@line_number</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Line:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@line</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Time:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@time</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Percentage:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@percentage</span>
-                </div>
-                """
-        )
-        self.profile_plot.add_tools(hover)
-
-        self.profile_plot.xaxis.visible = False
-        self.profile_plot.yaxis.visible = False
-        self.profile_plot.grid.visible = False
-
         self.ts_source = ColumnDataSource({'time': [], 'count': []})
         self.ts_plot = figure(title='Activity over time', height=100,
                               x_axis_type='datetime', active_drag='xbox_select',
@@ -591,7 +511,7 @@ class ProfileServer(DashboardComponent):
         self.state = profile.get_profile(self.log)
         data = profile.plot_data(self.state, profile_interval)
         self.states = data.pop('states')
-        self.source = ColumnDataSource(data=data)
+        self.profile_plot, self.source = profile.plot_figure(data, **kwargs)
 
         changing = [False]  # avoid repeated changes from within callback
 
@@ -624,47 +544,6 @@ class ProfileServer(DashboardComponent):
         else:
             self.source.on_change('selected', cb)
 
-        self.profile_plot = figure(tools='tap', height=400, **kwargs)
-        r = self.profile_plot.quad('left', 'right', 'top', 'bottom', color='color',
-                                   line_color='black', source=self.source)
-        r.selection_glyph = None
-        r.nonselection_glyph = None
-
-        hover = HoverTool(
-            point_policy="follow_mouse",
-            tooltips="""
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Name:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@name</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Filename:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@filename</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Line number:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@line_number</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Line:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@line</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Time:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@time</span>
-                </div>
-                <div>
-                    <span style="font-size: 14px; font-weight: bold;">Percentage:</span>&nbsp;
-                    <span style="font-size: 10px; font-family: Monaco, monospace;">@percentage</span>
-                </div>
-                """
-        )
-        self.profile_plot.add_tools(hover)
-
-        self.profile_plot.xaxis.visible = False
-        self.profile_plot.yaxis.visible = False
-        self.profile_plot.grid.visible = False
-
         self.ts_source = ColumnDataSource({'time': [], 'count': []})
         self.ts_plot = figure(title='Activity over time', height=100,
                               x_axis_type='datetime', active_drag='xbox_select',
