@@ -30,22 +30,22 @@ def test_nanny(s):
     with rpc(n.address) as nn:
         assert n.is_alive()
         assert s.ncores[n.worker_address] == 2
-        assert s.worker_info[n.worker_address]['services']['nanny'] > 1024
+        assert s.workers[n.worker_address].services['nanny'] > 1024
 
         yield nn.kill()
         assert not n.is_alive()
         assert n.worker_address not in s.ncores
-        assert n.worker_address not in s.worker_info
+        assert n.worker_address not in s.workers
 
         yield nn.kill()
         assert not n.is_alive()
         assert n.worker_address not in s.ncores
-        assert n.worker_address not in s.worker_info
+        assert n.worker_address not in s.workers
 
         yield nn.instantiate()
         assert n.is_alive()
         assert s.ncores[n.worker_address] == 2
-        assert s.worker_info[n.worker_address]['services']['nanny'] > 1024
+        assert s.workers[n.worker_address].services['nanny'] > 1024
 
         yield nn.terminate()
         assert not n.is_alive()
@@ -265,7 +265,8 @@ def test_nanny_timeout(c, s, a):
 
 
 @gen_cluster(ncores=[('127.0.0.1', 1)], client=True, Worker=Nanny,
-             worker_kwargs={'memory_limit': 1e8}, timeout=20)
+             worker_kwargs={'memory_limit': 1e8}, timeout=20,
+             check_new_threads=False)
 def test_nanny_terminate(c, s, a):
     from time import sleep
 
@@ -332,3 +333,13 @@ def test_wait_for_scheduler():
     log = log.getvalue()
     assert 'error' not in log.lower(), log
     assert 'restart' not in log.lower(), log
+
+
+@gen_cluster(ncores=[], client=True)
+def test_environment_variable(c, s):
+    a = Nanny(s.address, loop=s.loop, memory_limit=0, env={"FOO": "123"})
+    b = Nanny(s.address, loop=s.loop, memory_limit=0, env={"FOO": "456"})
+    yield [a._start(), b._start()]
+    results = yield c.run(lambda: os.environ['FOO'])
+    assert results == {a.worker_address: "123", b.worker_address: "456"}
+    yield [a._close(), b._close()]
