@@ -468,12 +468,9 @@ def assert_balanced(inp, expected, c, s, *workers):
       [1],
       [1]]),
 
-    pytest.mark.xfail(([[1, 1, 1, 1, 1, 1, 1],
-      [1, 1], [1, 1], [1, 1],
-      []],
-     [[1, 1, 1, 1, 1],
-      [1, 1], [1, 1], [1, 1],
-      [1, 1]]), reason="Some uncertainty based on executing stolen task")
+    pytest.param([[1, 1, 1, 1, 1, 1, 1], [1, 1], [1, 1], [1, 1], []],
+                 [[1, 1, 1, 1, 1], [1, 1], [1, 1], [1, 1], [1, 1]],
+                 marks=pytest.mark.xfail(reason="Some uncertainty based on executing stolen task"))
 ])
 def test_balance(inp, expected):
     test = lambda *args, **kwargs: assert_balanced(inp, expected, *args, **kwargs)
@@ -587,10 +584,12 @@ def test_dont_steal_long_running_tasks(c, s, a, b):
 
     yield gen.sleep(0.2)
 
-    assert sum(1 for k in s.processing[b.address] if k.startswith('long')) <= nb
-
     yield wait(long_tasks)
 
+    for t in long_tasks:
+        assert (sum(log[1] == 'executing' for log in a.story(t)) +
+                sum(log[1] == 'executing' for log in b.story(t))) <= 1
+
 
 @gen_cluster(client=True, ncores=[('127.0.0.1', 5)] * 2)
 def test_cleanup_repeated_tasks(c, s, a, b):
